# Universal Entity API

Universal Entity API is a plug-and-play Drupal module that
exposes deeply structured,
normalized JSON APIs for all content entities — ideal for decoupled frontends,
mobile apps, and content hubs.

## 🚀 Features

Universal Entity API transforms Drupal into a powerful backend
for headless and
decoupled architectures. It delivers structured, flexible APIs
for all major content types with full reference resolution,
smart rendering options and extensibility.

### Key API Endpoints
- `/api/{entity_type}/{bundle}/{id}` – Fetch any entity (Node, Media, Taxonomy,
  Block, Paragraph, etc.) with deeply resolved references
- `/api/node/{bundle}/list` – Paginated node listing with filtering, sorting,
  and field pruning
- `/api/block/{bundle}/list` – Retrieve custom block data
- `/api/menu/{menu_name}?depth=n` – Hierarchical menu with descriptions
  and field values
- `/api/entity-type/list` – Discover all entity types and bundles
- `/api/config/basic` – Returns selected config (site name, theme, logo, etc.)

### Enhancements
- Paragraphs inside Blocks
- Media inside Paragraphs
- Blocks inside Paragraphs
- Field filtering via `?fields=title,field_image`
- Sorting and pagination via `?sort=-created&page=1&limit=10`
- OpenAPI Support:
  - JSON schema at `/openapi.json`
  - Swagger UI available at `/api-docs`

## ⚙️ Post-Installation
Once enabled, the module is ready to use instantly —
no extra configuration required.

1. Visit `/api-docs` to explore and test APIs.
2. Try endpoints like `/api/node/article/1` or `/api/menu/main`.
3. Optional: Use Drupal’s permission and caching layers for API access control.
4. All APIs are fully extensible through hooks and services.

## 🔐 CORS Setup
To enable CORS in local development or production:

```php
$settings['cors.config'] = [
  'enabled' => TRUE,
  'allowedHeaders' => ['*'],
  'allowedMethods' => ['*'],
  'allowedOrigins' => ['*'],
  'exposedHeaders' => FALSE,
  'maxAge' => FALSE,
  'supportsCredentials' => FALSE,
];
```

Add this snippet to your `settings.php` or `services.yml`
as needed.

## 📦 Requirements
- Drupal 10 Core
- Layout Builder (optional, for layout API exposure)
- Paragraphs (optional, for nested content)
- Media (optional, for image and video fields)

## 🔌 Recommended Modules
- OpenAPI UI: Alternate interface for schema browsing
- Subrequests: For advanced batching (experimental)
- Decoupled Router: For frontend route resolution

## 🔁 Similar Projects
| Project         | Difference |
|----------------|------------|
| JSON:API       | Raw relationships, no deep normalization |
| GraphQL        | Complex, requires custom schemas and clients |
| REST UI        | Basic, no recursion or field filtering |
| Decoupled Router | Route-focused, not entity-focused |

## 🤝 Support This Module
- ⭐ Star the project on Drupal.org
- 💡 Submit patches or feature ideas
- 🐞 Open issues or documentation examples
- 🤝 Contact us for co-maintainership or integrations

## 📚 Community Documentation
- 🎥 Live demo and walkthrough – Coming soon
- 🧩 Next.js integration video – Planned
- 🔧 GitLab decoupled starter repo – Coming soon
- 📚 API docs: `/api-docs`
- **Layout Builder API (in development)**:
- `/api/layout/node/{id}` exposes layout sections, fields, blocks,
  and inline content
  - Paragraphs, media, and nested blocks normalized recursively
  - Returns both structured JSON and rendered output for frontend mapping
