<?php

namespace Drupal\universal_entity_api\Controller;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\JsonResponse;

/**
 * Controller for retrieving basic site configuration via API.
 */
class ConfigController extends ControllerBase {

  /**
   * The config factory service.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected ConfigFactoryInterface $configFactory;

  /**
   * Constructs a ConfigController object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   The config factory.
   */
  public function __construct(ConfigFactoryInterface $configFactory) {
    $this->configFactory = $configFactory;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory')
    );
  }

  /**
   * Returns basic site configuration.
   *
   * This method retrieves various site configuration settings such as
   * site name, site email, default language, and timezone, and returns
   * them as a JSON response.
   *
   * @return \Symfony\Component\HttpFoundation\JsonResponse
   *   The JSON response containing basic site configuration.
   */
  public function basic() {
    $site_config = $this->configFactory->get('system.site');
    $lang_config = $this->configFactory->get('language.types');
    $date_config = $this->configFactory->get('system.date');

    return new JsonResponse([
      'site_name' => $site_config->get('name'),
      'site_mail' => $site_config->get('mail'),
      'default_language' => $lang_config->get('configurable')[0] ?? 'en',
      'timezone' => $date_config->get('timezone.default'),
    ]);
  }

}
