<?php

namespace Drupal\universal_entity_api\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\universal_entity_api\Normalizer\MenuNormalizer;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\JsonResponse;

/**
 * Controller for retrieving menu data via API.
 */
class MenuApiController extends ControllerBase {

  /**
   * The menu normalizer service.
   *
   * @var \Drupal\universal_entity_api\Normalizer\MenuNormalizer
   */
  protected MenuNormalizer $normalizer;

  /**
   * Constructs a MenuApiController object.
   *
   * @param \Drupal\universal_entity_api\Normalizer\MenuNormalizer $normalizer
   *   The menu normalizer.
   */
  public function __construct(MenuNormalizer $normalizer) {
    $this->normalizer = $normalizer;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('universal_entity_api.menu_normalizer')
    );
  }

  /**
   * Handles menu API requests.
   *
   * This method normalizes the specified menu and returns its data
   * as a JSON response with caching headers.
   *
   * @param string $menu_name
   *   The machine name of the menu to retrieve.
   *
   * @return \Symfony\Component\HttpFoundation\JsonResponse
   *   The JSON response containing the menu data.
   */
  public function handle($menu_name) {
    $data = $this->normalizer->normalize($menu_name);
    $response = new JsonResponse($data);
    $response->setMaxAge(3600);
    $response->headers->set('Cache-Control', 'public');
    return $response;
  }

}
