<?php

namespace Drupal\universal_entity_api\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Extension\ModuleExtensionList;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Response;

/**
 * Controller for displaying the Swagger UI.
 */
class SwaggerUiController extends ControllerBase {

  /**
   * The module extension list service.
   *
   * @var \Drupal\Core\Extension\ModuleExtensionList
   */
  protected ModuleExtensionList $moduleExtensionList;

  /**
   * Constructs a new SwaggerUiController object.
   *
   * @param \Drupal\Core\Extension\ModuleExtensionList $moduleExtensionList
   *   The module extension list service.
   */
  public function __construct(ModuleExtensionList $moduleExtensionList) {
    $this->moduleExtensionList = $moduleExtensionList;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('extension.list.module')
    );
  }

  /**
   * Display the Swagger UI HTML page.
   *
   * The HTML page served by this method is the standard Swagger UI HTML page
   * that comes with the module. The only modification is that the default
   * Swagger spec URL is replaced with the URL of the OpenAPI specification
   * served by this module.
   *
   * @return \Symfony\Component\HttpFoundation\Response
   *   The HTML page to display.
   */
  public function display() {
    $module_path = $this->moduleExtensionList->getPath('universal_entity_api');
    $html = file_get_contents($module_path . '/swagger-ui/index.html');

    // Replace default Swagger spec URL with your local one.
    $html = str_replace('https://petstore.swagger.io/v2/swagger.json', '/openapi.json', $html);

    return new Response($html, 200, ['Content-Type' => 'text/html']);
  }

}
