<?php

namespace Drupal\universal_entity_api\Normalizer;

use Drupal\Core\Entity\EntityInterface;
use Drupal\universal_entity_api\Service\EntitySerializer;

/**
 * Normalizes block entities.
 */
class BlockNormalizer {

  /**
   * The entity serializer service.
   *
   * @var \Drupal\universal_entity_api\Service\EntitySerializer
   */
  protected EntitySerializer $serializer;

  /**
   * Constructs a BlockNormalizer object.
   *
   * @param \Drupal\universal_entity_api\Service\EntitySerializer $serializer
   *   The entity serializer.
   */
  public function __construct(EntitySerializer $serializer) {
    $this->serializer = $serializer;
  }

  /**
   * Normalizes an array of block entities.
   *
   * @param \Drupal\Core\Entity\EntityInterface[] $blocks
   *   An array of block entities to normalize.
   *
   * @return array
   *   An array of normalized block data.
   */
  public function normalize(array $blocks): array {
    return array_map(function (EntityInterface $block) {
      return $this->serializer->normalize($block);
    }, $blocks);
  }

}
