<?php

namespace Drupal\universal_entity_api\Normalizer;

use Drupal\Core\Entity\EntityInterface;
use Drupal\universal_entity_api\Service\EntitySerializer;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Normalizes paragraph entities.
 */
class ParagraphNormalizer {

  /**
   * The dependency injection container.
   *
   * @var \Symfony\Component\DependencyInjection\ContainerInterface
   */
  protected ContainerInterface $container;

  /**
   * Constructs a ParagraphNormalizer object.
   *
   * @param \Symfony\Component\DependencyInjection\ContainerInterface $container
   *   The container.
   */
  public function __construct(ContainerInterface $container) {
    $this->container = $container;
  }

  /**
   * Gets the entity serializer service.
   *
   * @return \Drupal\universal_entity_api\Service\EntitySerializer
   *   The entity serializer service.
   */
  protected function getSerializer(): EntitySerializer {
    return $this->container->get('universal_entity_api.serializer');
  }

  /**
   * Normalizes an array of paragraph entities.
   *
   * @param \Drupal\Core\Entity\EntityInterface[] $paragraphs
   *   An array of paragraph entities to normalize.
   *
   * @return array
   *   An array of normalized paragraph data.
   */
  public function normalize(array $paragraphs): array {
    return array_map(function (EntityInterface $entity) {
      return $this->getSerializer()->normalize($entity);
    }, $paragraphs);
  }

}
